package com.loafle.bridge.discoveryport.repository;

import com.loafle.bridge.Application;
import com.loafle.bridge.discoveryport.constant.DirectionType;
import com.loafle.bridge.discoveryport.constant.PortType;
import com.loafle.bridge.discoveryport.entity.DiscoveryPort;
import com.loafle.bridge.discoveryport.entity.ServiceScanHistory;
import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static org.junit.Assert.assertEquals;

/**
 * Created by root on 16. 11. 15.
 */

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = Application.class)
public class DiscoveryPortRepositoryTest {



    @Autowired
    private DiscoveryPortRepository repo;

    Logger l = Logger.getLogger(this.getClass());


    @Before
    public void Before() {
        repo.save(new DiscoveryPort(PortType.TCP,null ,(short)1, new Date(), new Date()));
        repo.save(new DiscoveryPort(PortType.UDP,null , (short)2, new Date(), new Date()));
        repo.save(new DiscoveryPort(PortType.TCP,null , (short)3, new Date(), new Date()));
        repo.save(new DiscoveryPort(PortType.UDP,null , (short)4, new Date(), new Date()));
        repo.save(new DiscoveryPort(PortType.TCP,null , (short)5, new Date(), new Date()));
    }

    @After
    public void After() {
        repo.deleteAll();
    }

    @Test
    public void TestInsertPort() {
        DiscoveryPort p = new DiscoveryPort(PortType.TCP, null ,(short)1, new Date(), new Date());

        repo.save(p);
        DiscoveryPort compare = repo.findOne(p.getId());

        assertEquals(p.getId(),compare.getId());

        l.debug(p.getId());
        l.debug(p.getType());
        l.debug(p.getPortNumber());
        l.debug(p.getCreateAt());
        l.debug(p.getUpdateAt());

    }

    @Test
    @Transactional
    public void TestInsertServiceHistory() {
        List<DiscoveryPort> list = repo.findAll();

        DiscoveryPort p = list.get(0);

        List<ServiceScanHistory> h = new ArrayList<ServiceScanHistory>();
        byte [] a = {10,20,30,40,50};
        h.add(new ServiceScanHistory(p,"testservice1", DirectionType.S,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice2", DirectionType.R,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice3", DirectionType.S,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice4", DirectionType.R,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice5", DirectionType.S,a, new Date()));

        p.setHistories(h);
        repo.save(p);

        repo.flush();
        DiscoveryPort find = repo.findOne(p.getId());

        List<ServiceScanHistory> l1 = p.getHistories();
        List<ServiceScanHistory> l2 = find.getHistories();

        assertEquals(l1.size(), l2.size());
    }
}